## Version 0.0.38

This new version introduces a new dependency to the project, enhancing the project root path management.

### New Features

- Added pyprojroot to the list of dependencies for better project root path management (69444d) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
